@@ -110,7 +110,7 @@ if [ -n "${NO_TESTS}" ]
 then
   EXTRA_CMAKE_FLAGS="${EXTRA_CMAKE_FLAGS} -DBUILD_TESTING=''"
 else
-  EXTRA_CMAKE_FLAGS="${EXTRA_CMAKE_FLAGS} -DINSTALL_GTEST=''"
+  EXTRA_CMAKE_FLAGS="${EXTRA_CMAKE_FLAGS} -DBUILD_TESTING='ON' -DINSTALL_GTEST=''"
 fi
 
 cd ${BUILD_DIR}
@@ -149,6 +149,8 @@ then
   mkdir AppDir
   tar xf TinyTeX-1-v2022.04.04.tar.xz -C AppDir/
   mv AppDir/.TinyTeX AppDir/usr
+  mkdir -p AppDir/usr/share
+  [ -d /usr/share/gtksourceview-4 ] && cp -rv /usr/share/gtksourceview-4 AppDir/usr/share/ || echo "!! /usr/share/gtksourceview-4 NOT FOUND !!"
   DESTDIR=AppDir ninja install
   ./linuxdeploy-x86_64.AppImage \
         --appdir AppDir \
