@@ -1,5 +1,4 @@
 #!/usr/bin/env python3
-# -*- coding: UTF-8 -*-
 
 import os
 import re
@@ -16,7 +15,7 @@ DEBIAN_CHANGELOG_PATH = os.path.join(ROOT_DIR, "debian", "changelog")
 VERSION = "?"
 with open(DEBIAN_CHANGELOG_PATH, "rb") as fd:
     for fileline in fd:
-        match = re.search(b"cherrytree +\(([0-9]+\.[0-9]+\.[0-9]+)[-+]", fileline)
+        match = re.search(b"cherrytree +\\(([0-9]+\\.[0-9]+\\.[0-9]+)[-+]", fileline)
         if match is not None:
             VERSION = str(match.group(1))
             #print(VERSION)
