@@ -325,18 +325,17 @@ TocEntry find_toc_entries(CtActions& actions, CtTreeIter& node, unsigned depth)
 {
     const int node_id = node.get_node_id();
     TocEntry entry{fmt::format("node {}", node_id), true/*is_node*/, node.get_node_name(), depth};
-    const std::string scale_tag{"scale_"};
     std::unordered_map<int, int> encountered_headers;
-    Glib::RefPtr<Gtk::TextBuffer> rTextBuffer = node.get_node_text_buffer();
-    if (not rTextBuffer) {
+    Glib::RefPtr<Gtk::TextBuffer> pTextBuffer = node.get_node_text_buffer();
+    if (not pTextBuffer) {
         throw std::runtime_error(str::format(_("Failed to retrieve the content of the node '%s'"), node.get_node_name().raw()));
     }
-    Gtk::TextIter text_iter = rTextBuffer->begin();
+    Gtk::TextIter text_iter = pTextBuffer->begin();
 
     do {
-        std::optional<Glib::ustring> tag_name = CtTextIterUtil::iter_get_tag_startingwith(text_iter, scale_tag);
+        std::optional<Glib::ustring> tag_name = CtTextIterUtil::iter_get_tag_startingwith(text_iter, CtConst::TAG_SCALE_PREFIX);
         if (tag_name and not Glib::str_has_suffix(tag_name.value(), CtConst::TAG_PROP_VAL_SMALL)) {
-            const Glib::ustring h_level_str = tag_name.value().substr(scale_tag.length() + 1);
+            const Glib::ustring h_level_str = tag_name.value().substr(CtConst::TAG_SCALE_PREFIX.length() + 1);
             try {
                 const int h_lvl = std::stoi(h_level_str);
                 ++encountered_headers[h_lvl];
@@ -354,12 +353,12 @@ TocEntry find_toc_entries(CtActions& actions, CtTreeIter& node, unsigned depth)
                 Glib::ustring txt{start_iter, end_iter};
                 spdlog::debug("{} - {}", txt.raw(), txt.size());
 
-                auto mark = rTextBuffer->create_mark(end_iter, false);
+                auto mark = pTextBuffer->create_mark(end_iter, false);
 
                 CtAnchorExpCollState expCollState{CtAnchorExpCollState::Expanded};
-                Glib::RefPtr<Gtk::TextChildAnchor> rChildAnchor = end_iter.get_child_anchor();
-                if (rChildAnchor) {
-                    CtAnchoredWidget* pCtAnchoredWidget = node.get_anchored_widget(rChildAnchor);
+                Glib::RefPtr<Gtk::TextChildAnchor> pChildAnchor = end_iter.get_child_anchor();
+                if (pChildAnchor) {
+                    CtAnchoredWidget* pCtAnchoredWidget = node.get_anchored_widget(pChildAnchor);
                     if (pCtAnchoredWidget) {
                         auto pCtImageAnchor = dynamic_cast<CtImageAnchor*>(pCtAnchoredWidget);
                         if (pCtImageAnchor and 0 != CtStrUtil::is_header_anchor_name(pCtImageAnchor->get_anchor_name())) {
@@ -369,8 +368,8 @@ TocEntry find_toc_entries(CtActions& actions, CtTreeIter& node, unsigned depth)
                             const int endOffset = end_iter.get_offset();
                             auto iter_bound = end_iter;
                             iter_bound.forward_char();
-                            rTextBuffer->erase(end_iter, iter_bound);
-                            end_iter = rTextBuffer->get_iter_at_offset(endOffset);
+                            pTextBuffer->erase(end_iter, iter_bound);
+                            end_iter = pTextBuffer->get_iter_at_offset(endOffset);
                         }
                     }
                 }
@@ -378,7 +377,7 @@ TocEntry find_toc_entries(CtActions& actions, CtTreeIter& node, unsigned depth)
                 actions.image_insert_anchor(end_iter, anchor_txt, expCollState, CtConst::TAG_PROP_VAL_RIGHT);
 
                 text_iter = mark->get_iter();
-                rTextBuffer->delete_mark(mark);
+                pTextBuffer->delete_mark(mark);
                 //spdlog::debug("INSERT DONE");
                 entry.children.emplace_back(fmt::format("node {} {}", node_id, anchor_txt), false/*is_node*/, txt, depth + 1, h_lvl);
             }
@@ -715,11 +714,11 @@ void CtActions::text_row_selection_duplicate()
 void CtActions::text_row_up()
 {
     auto proof = _get_text_view_n_buffer_codebox_proof();
-    if (not proof.text_view->get_buffer()) return;
+    auto pTextBuffer = proof.text_view->get_buffer();
+    if (not pTextBuffer) return;
     if (not _is_curr_node_not_read_only_or_error()) return;
 
-    auto text_buffer = proof.text_view->get_buffer();
-    CtTextRange range = CtList{_pCtConfig, text_buffer}.get_paragraph_iters();
+    CtTextRange range = CtList{_pCtConfig, pTextBuffer}.get_paragraph_iters();
     range.iter_end.forward_char();
     bool missing_leading_newline = false;
     Gtk::TextIter destination_iter = range.iter_start;
@@ -740,54 +739,57 @@ void CtActions::text_row_up()
     int destination_offset = destination_iter.get_offset();
     int start_offset = range.iter_start.get_offset();
     int end_offset = range.iter_end.get_offset();
-    //#print "iter_start %s %s '%s'" % (start_offset, ord(iter_start.get_char()), iter_start.get_char())
-    //#print "iter_end %s %s '%s'" % (end_offset, ord(iter_end.get_char()), iter_end.get_char())
-    //#print "destination_iter %s %s '%s'" % (destination_offset, ord(destination_iter.get_char()), destination_iter.get_char())
-    Glib::ustring text_to_move = text_buffer->get_text(range.iter_start, range.iter_end);
+    Glib::ustring text_to_move = pTextBuffer->get_text(range.iter_start, range.iter_end);
     int diff_offsets = end_offset - start_offset;
     if (proof.codebox or proof.table or proof.syntax_highl != CtConst::RICH_TEXT_ID) {
-        text_buffer->erase(range.iter_start, range.iter_end);
-        destination_iter = text_buffer->get_iter_at_offset(destination_offset);
+        pTextBuffer->erase(range.iter_start, range.iter_end);
+        destination_iter = pTextBuffer->get_iter_at_offset(destination_offset);
         if (text_to_move.empty() or text_to_move[text_to_move.length()-1] != '\n') {
             diff_offsets += 1;
             text_to_move += CtConst::CHAR_NEWLINE;
         }
-        text_buffer->move_mark(text_buffer->get_insert(), destination_iter);
-        text_buffer->insert(destination_iter, text_to_move);
+        pTextBuffer->move_mark(pTextBuffer->get_insert(), destination_iter);
+        pTextBuffer->insert(destination_iter, text_to_move);
         proof.text_view->set_selection_at_offset_n_delta(destination_offset, diff_offsets-1);
     }
     else {
+        // if any text is collapsed between destination_offset and start_offset we must expand that
+        //spdlog::debug("{},{},'{}'", destination_offset, start_offset - destination_offset,
+        //    pTextBuffer->get_text(pTextBuffer->get_iter_at_offset(destination_offset), pTextBuffer->get_iter_at_offset(start_offset)).c_str());
+        if (proof.text_view->expand_collapsed_anchors(destination_offset - 1, start_offset - destination_offset, pTextBuffer) > 0) {
+            return;
+        }
         Glib::ustring rich_text = CtClipboard{_pCtMainWin}.rich_text_get_from_text_buffer_selection(
             _pCtMainWin->curr_tree_iter(),
-            text_buffer,
+            pTextBuffer,
             range.iter_start,
             range.iter_end,
             'n',
             true/*exclude_iter_sel_end*/);
-        text_buffer->erase(range.iter_start, range.iter_end);
-        destination_iter = text_buffer->get_iter_at_offset(destination_offset);
+        pTextBuffer->erase(range.iter_start, range.iter_end);
+        destination_iter = pTextBuffer->get_iter_at_offset(destination_offset);
         if (destination_offset > 0) {
             // clear the newline from any tag
-            Gtk::TextIter clr_start_iter = text_buffer->get_iter_at_offset(destination_offset-1);
-            text_buffer->remove_all_tags(clr_start_iter, destination_iter);
+            Gtk::TextIter clr_start_iter = pTextBuffer->get_iter_at_offset(destination_offset-1);
+            pTextBuffer->remove_all_tags(clr_start_iter, destination_iter);
         }
         bool append_newline = false;
         if (text_to_move.empty() or text_to_move[text_to_move.length()-1] != '\n') {
             diff_offsets += 1;
             append_newline = true;
         }
-        text_buffer->move_mark(text_buffer->get_insert(), destination_iter);
+        pTextBuffer->move_mark(pTextBuffer->get_insert(), destination_iter);
         // trick of space to prevent subsequent text to take pasted text tag(s)
-        text_buffer->insert_at_cursor(CtConst::CHAR_SPACE);
-        destination_iter = text_buffer->get_iter_at_offset(destination_offset);
-        text_buffer->move_mark(text_buffer->get_insert(), destination_iter);
+        pTextBuffer->insert_at_cursor(CtConst::CHAR_SPACE);
+        destination_iter = pTextBuffer->get_iter_at_offset(destination_offset);
+        pTextBuffer->move_mark(pTextBuffer->get_insert(), destination_iter);
         // write moved line
-        CtClipboard{_pCtMainWin}.from_xml_string_to_buffer(text_buffer, rich_text);
+        CtClipboard{_pCtMainWin}.from_xml_string_to_buffer(pTextBuffer, rich_text);
         if (append_newline)
-            text_buffer->insert_at_cursor(CtConst::CHAR_NEWLINE);
+            pTextBuffer->insert_at_cursor(CtConst::CHAR_NEWLINE);
         // clear space trick
-        Gtk::TextIter cursor_iter = text_buffer->get_iter_at_mark(text_buffer->get_insert());
-        text_buffer->erase(cursor_iter, text_buffer->get_iter_at_offset(cursor_iter.get_offset()+1));
+        Gtk::TextIter cursor_iter = pTextBuffer->get_iter_at_mark(pTextBuffer->get_insert());
+        pTextBuffer->erase(cursor_iter, pTextBuffer->get_iter_at_offset(cursor_iter.get_offset()+1));
         // selection
         proof.text_view->set_selection_at_offset_n_delta(destination_offset, diff_offsets-1);
     }
@@ -798,11 +800,11 @@ void CtActions::text_row_up()
 void CtActions::text_row_down()
 {
     auto proof = _get_text_view_n_buffer_codebox_proof();
-    if (not proof.text_view->get_buffer()) return;
+    auto pTextBuffer = proof.text_view->get_buffer();
+    if (not pTextBuffer) return;
     if (not _is_curr_node_not_read_only_or_error()) return;
 
-    auto text_buffer = proof.text_view->get_buffer();
-    CtTextRange range = CtList{_pCtConfig, text_buffer}.get_paragraph_iters();
+    CtTextRange range = CtList{_pCtConfig, pTextBuffer}.get_paragraph_iters();
     if (not range.iter_end.forward_char()) return;
     int missing_leading_newline = false;
     Gtk::TextIter destination_iter = range.iter_end;
@@ -816,15 +818,12 @@ void CtActions::text_row_down()
     int destination_offset = destination_iter.get_offset();
     int start_offset = range.iter_start.get_offset();
     int end_offset = range.iter_end.get_offset();
-    //#print "iter_start %s %s '%s'" % (start_offset, ord(iter_start.get_char()), iter_start.get_char())
-    //#print "iter_end %s %s '%s'" % (end_offset, ord(iter_end.get_char()), iter_end.get_char())
-    //#print "destination_iter %s %s '%s'" % (destination_offset, ord(destination_iter.get_char()), destination_iter.get_char())
-    Glib::ustring text_to_move = text_buffer->get_text(range.iter_start, range.iter_end);
+    Glib::ustring text_to_move = pTextBuffer->get_text(range.iter_start, range.iter_end);
     int diff_offsets = end_offset - start_offset;
     if (proof.codebox or proof.table or proof.syntax_highl != CtConst::RICH_TEXT_ID) {
-        text_buffer->erase(range.iter_start, range.iter_end);
+        pTextBuffer->erase(range.iter_start, range.iter_end);
         destination_offset -= diff_offsets;
-        destination_iter = text_buffer->get_iter_at_offset(destination_offset);
+        destination_iter = pTextBuffer->get_iter_at_offset(destination_offset);
         if (text_to_move.empty() or text_to_move[text_to_move.length() - 1] != '\n') {
             diff_offsets += 1;
             text_to_move += CtConst::CHAR_NEWLINE;
@@ -833,49 +832,53 @@ void CtActions::text_row_down()
             diff_offsets += 1;
             text_to_move = CtConst::CHAR_NEWLINE + text_to_move;
         }
-        text_buffer->insert(destination_iter, text_to_move);
+        pTextBuffer->insert(destination_iter, text_to_move);
         if (not missing_leading_newline)
             proof.text_view->set_selection_at_offset_n_delta(destination_offset, diff_offsets-1);
         else
             proof.text_view->set_selection_at_offset_n_delta(destination_offset+1, diff_offsets-2);
     }
     else {
+        // if any text is collapsed between end_offset and destination_offset we must expand that
+        if (proof.text_view->expand_collapsed_anchors(end_offset, destination_offset - end_offset, pTextBuffer) > 0) {
+            return;
+        }
         Glib::ustring rich_text = CtClipboard{_pCtMainWin}.rich_text_get_from_text_buffer_selection(
             _pCtMainWin->curr_tree_iter(),
-            text_buffer,
+            pTextBuffer,
             range.iter_start,
             range.iter_end,
             'n',
             true/*exclude_iter_sel_end*/);
-        text_buffer->erase(range.iter_start, range.iter_end);
+        pTextBuffer->erase(range.iter_start, range.iter_end);
         destination_offset -= diff_offsets;
-        destination_iter = text_buffer->get_iter_at_offset(destination_offset);
+        destination_iter = pTextBuffer->get_iter_at_offset(destination_offset);
         if (destination_offset > 0) {
             // clear the newline from any tag
-            Gtk::TextIter clr_start_iter = text_buffer->get_iter_at_offset(destination_offset-1);
-            text_buffer->remove_all_tags(clr_start_iter, destination_iter);
+            Gtk::TextIter clr_start_iter = pTextBuffer->get_iter_at_offset(destination_offset-1);
+            pTextBuffer->remove_all_tags(clr_start_iter, destination_iter);
         }
         bool append_newline = false;
         if (text_to_move.empty() or text_to_move[text_to_move.length()-1] != '\n') {
             diff_offsets += 1;
             append_newline = true;
         }
-        text_buffer->move_mark(text_buffer->get_insert(), destination_iter);
+        pTextBuffer->move_mark(pTextBuffer->get_insert(), destination_iter);
         if (missing_leading_newline) {
             diff_offsets += 1;
-            text_buffer->insert_at_cursor(CtConst::CHAR_NEWLINE);
+            pTextBuffer->insert_at_cursor(CtConst::CHAR_NEWLINE);
         }
         // trick of space to prevent subsequent text to take pasted text tag(s)
-        text_buffer->insert_at_cursor(CtConst::CHAR_SPACE);
-        destination_iter = text_buffer->get_iter_at_offset(destination_offset);
-        text_buffer->move_mark(text_buffer->get_insert(), destination_iter);
+        pTextBuffer->insert_at_cursor(CtConst::CHAR_SPACE);
+        destination_iter = pTextBuffer->get_iter_at_offset(destination_offset);
+        pTextBuffer->move_mark(pTextBuffer->get_insert(), destination_iter);
         // write moved line
-        CtClipboard{_pCtMainWin}.from_xml_string_to_buffer(text_buffer, rich_text);
+        CtClipboard{_pCtMainWin}.from_xml_string_to_buffer(pTextBuffer, rich_text);
         if (append_newline)
-            text_buffer->insert_at_cursor(CtConst::CHAR_NEWLINE);
+            pTextBuffer->insert_at_cursor(CtConst::CHAR_NEWLINE);
         // clear space trick
-        Gtk::TextIter cursor_iter = text_buffer->get_iter_at_mark(text_buffer->get_insert());
-        text_buffer->erase(cursor_iter, text_buffer->get_iter_at_offset(cursor_iter.get_offset()+1));
+        Gtk::TextIter cursor_iter = pTextBuffer->get_iter_at_mark(pTextBuffer->get_insert());
+        pTextBuffer->erase(cursor_iter, pTextBuffer->get_iter_at_offset(cursor_iter.get_offset()+1));
         // selection
         if (not missing_leading_newline)
             proof.text_view->set_selection_at_offset_n_delta(destination_offset, diff_offsets-1);
