@@ -65,6 +65,44 @@ CtClipboard::CtClipboard(CtMainWin* pCtMainWin)
     clipb._paste_clipboard(Glib::wrap(pTextView), ctPairCodeboxMainWin.first);
 }
 
+bool CtClipboard::_extend_selection_if_collapsed_text(Gtk::TextIter& iter_sel_end, const CtTreeIter& ctTreeIter)
+{
+    if ('\n' == iter_sel_end.get_char()) {
+        Gtk::TextIter iter_tmp = iter_sel_end;
+        if (iter_tmp.backward_char()) {
+            Glib::RefPtr<Gtk::TextChildAnchor> pChildAnchor = iter_tmp.get_child_anchor();
+            if (pChildAnchor) {
+                CtAnchoredWidget* pCtAnchoredWidget = ctTreeIter.get_anchored_widget(pChildAnchor);
+                if (pCtAnchoredWidget) {
+                    auto pCtImageAnchor = dynamic_cast<CtImageAnchor*>(pCtAnchoredWidget);
+                    if (pCtImageAnchor and
+                        0 != CtStrUtil::is_header_anchor_name(pCtImageAnchor->get_anchor_name()) and
+                        CtAnchorExpCollState::Collapsed == pCtImageAnchor->get_exp_coll_state())
+                    {
+                        // we must include the hidden collapsed text in the copy
+                        const std::string tagPropVal{"h" + std::to_string(CtStrUtil::is_header_anchor_name(pCtImageAnchor->get_anchor_name()))};
+                        const std::string tagNameInvis = _pCtMainWin->get_text_tag_name_exist_or_create(CtConst::TAG_INVISIBLE, tagPropVal);
+                        Glib::RefPtr<Gtk::TextTag> pTextTagInvis = _pCtMainWin->get_text_tag_table()->lookup(tagNameInvis);
+                        if (iter_tmp.forward_to_tag_toggle(pTextTagInvis)) {
+                            const auto toggled_on = iter_tmp.get_toggled_tags(true/*toggled_on*/);
+                            for (const auto& pCurrTag : toggled_on) {
+                                if (pCurrTag->property_name() == tagNameInvis) {
+                                    // found the start as expected, now we need to move to the end
+                                    (void)iter_tmp.forward_to_tag_toggle(pTextTagInvis);
+                                    iter_sel_end = iter_tmp;
+                                    spdlog::debug("forwarded selection end to include collapsed section");
+                                    return true;
+                                }
+                            }
+                        }
+                    }
+                }
+            }
+        }
+    }
+    return false;
+}
+
 // Cut to Clipboard
 void CtClipboard::_cut_clipboard(Gtk::TextView* pTextView, CtCodebox* pCodebox)
 {
@@ -73,14 +111,17 @@ void CtClipboard::_cut_clipboard(Gtk::TextView* pTextView, CtCodebox* pCodebox)
     if (text_buffer->get_has_selection()) {
         Gtk::TextIter iter_sel_start, iter_sel_end;
         text_buffer->get_selection_bounds(iter_sel_start, iter_sel_end);
-        int num_chars = iter_sel_end.get_offset() - iter_sel_start.get_offset();
-        if ((pCodebox or _pCtMainWin->curr_tree_iter().get_node_syntax_highlighting() != CtConst::RICH_TEXT_ID) and
-            num_chars > 30000)
-        {
+        const int num_chars = iter_sel_end.get_offset() - iter_sel_start.get_offset();
+        const CtTreeIter ctTreeIter = _pCtMainWin->curr_tree_iter();
+        const bool isRichText = ctTreeIter.get_node_is_rich_text();
+        if ((pCodebox or not isRichText) and num_chars > 30000) {
             spdlog::warn("cut-clipboard not overridden for num_chars {}", num_chars);
         }
         else {
             g_signal_stop_emission_by_name(G_OBJECT(pTextView->gobj()), "cut-clipboard");
+            if (isRichText) {
+                (void)_extend_selection_if_collapsed_text(iter_sel_end, ctTreeIter);
+            }
             _selection_to_clipboard(text_buffer, pTextView, iter_sel_start, iter_sel_end, num_chars, pCodebox);
             if (_pCtMainWin->get_ct_actions()->_is_curr_node_not_read_only_or_error()) {
                 text_buffer->erase_selection(true, pTextView->get_editable());
@@ -108,14 +149,17 @@ void CtClipboard::_copy_clipboard(Gtk::TextView* pTextView, CtCodebox* pCodebox)
     if (text_buffer->get_has_selection()) {
         Gtk::TextIter iter_sel_start, iter_sel_end;
         text_buffer->get_selection_bounds(iter_sel_start, iter_sel_end);
-        int num_chars = iter_sel_end.get_offset() - iter_sel_start.get_offset();
-        if ((pCodebox or _pCtMainWin->curr_tree_iter().get_node_syntax_highlighting() != CtConst::RICH_TEXT_ID) and
-            num_chars > 30000)
-        {
+        const int num_chars = iter_sel_end.get_offset() - iter_sel_start.get_offset();
+        const CtTreeIter ctTreeIter = _pCtMainWin->curr_tree_iter();
+        const bool isRichText = ctTreeIter.get_node_is_rich_text();
+        if ((pCodebox or not isRichText) and num_chars > 30000) {
             spdlog::warn("copy-clipboard not overridden for num_chars {}", num_chars);
         }
         else {
             g_signal_stop_emission_by_name(G_OBJECT(pTextView->gobj()), "copy-clipboard");
+            if (isRichText) {
+                (void)_extend_selection_if_collapsed_text(iter_sel_end, ctTreeIter);
+            }
             _selection_to_clipboard(text_buffer, pTextView, iter_sel_start, iter_sel_end, num_chars, pCodebox);
         }
     }
@@ -221,7 +265,7 @@ void CtClipboard::table_row_to_clipboard(CtTableCommon* pTable)
     pTable->to_xml(clip_data->xml_doc.create_root_node("root"), 0, nullptr, std::string{});
     clip_data->html_text = CtExport2Html{_pCtMainWin}.table_export_to_html(pTable);
 
-    _set_clipboard_data({CtConst::TARGET_CTD_TABLE, CtConst::TARGETS_HTML[0]}, clip_data);
+    _set_clipboard_data({CtConst::TARGET_CTD_TABLE, CtConst::TARGETS_HTML[0], CtConst::TARGETS_HTML[1]}, clip_data);
 }
 
 void CtClipboard::table_row_paste(CtTableCommon* pTable)
@@ -243,7 +287,7 @@ void CtClipboard::table_column_to_clipboard(CtTableCommon* pTable)
     pTable->to_xml(clip_data->xml_doc.create_root_node("root"), 0, nullptr, std::string{});
     clip_data->html_text = CtExport2Html{_pCtMainWin}.table_export_to_html(pTable);
 
-    _set_clipboard_data({CtConst::TARGET_CTD_TABLE, CtConst::TARGETS_HTML[0]}, clip_data);
+    _set_clipboard_data({CtConst::TARGET_CTD_TABLE, CtConst::TARGETS_HTML[0], CtConst::TARGETS_HTML[1]}, clip_data);
 }
 
 void CtClipboard::table_column_paste(CtTableCommon* pTable)
@@ -396,7 +440,7 @@ void CtClipboard::_selection_to_clipboard(Glib::RefPtr<Gtk::TextBuffer> text_buf
                 clip_data->html_text = CtExport2Html{_pCtMainWin}.table_export_to_html(table);
                 clip_data->plain_text = CtExport2Txt{_pCtMainWin}.get_table_plain(table);
 
-                _set_clipboard_data({CtConst::TARGET_CTD_TABLE, CtConst::TARGETS_HTML[0], CtConst::TARGET_CTD_PLAIN_TEXT}, clip_data);
+                _set_clipboard_data({CtConst::TARGET_CTD_TABLE, CtConst::TARGETS_HTML[0], CtConst::TARGETS_HTML[1], CtConst::TARGET_CTD_PLAIN_TEXT}, clip_data);
                 return;
             }
             else if (auto codebox = dynamic_cast<CtCodebox*>(widget_vector.front())) {
@@ -409,7 +453,7 @@ void CtClipboard::_selection_to_clipboard(Glib::RefPtr<Gtk::TextBuffer> text_buf
                 else {
                     clip_data->plain_text = CtExport2Txt{_pCtMainWin}.get_codebox_plain(codebox);
                 }
-                _set_clipboard_data({CtConst::TARGET_CTD_CODEBOX, CtConst::TARGETS_HTML[0], CtConst::TARGET_CTD_PLAIN_TEXT}, clip_data);
+                _set_clipboard_data({CtConst::TARGET_CTD_CODEBOX, CtConst::TARGETS_HTML[0], CtConst::TARGETS_HTML[1], CtConst::TARGET_CTD_PLAIN_TEXT}, clip_data);
                 return;
             }
         }
