@@ -1,7 +1,7 @@
 /*
  * ct_const.h
  *
- * Copyright 2009-2024
+ * Copyright 2009-2025
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -134,17 +134,29 @@ const inline static std::array<std::string,NUM_USER_STYLES> USER_STYLE_LINE_NUMB
 
 const inline static gchar* GTKSPELLCHECK_TAG_NAME  {"gtkspellchecker-misspelled"};
 const inline static gchar* TAG_WEIGHT              {"weight"};
+const inline static Glib::ustring TAG_WEIGHT_PREFIX         {"weight_"};
 const inline static gchar* TAG_FOREGROUND          {"foreground"};
+const inline static Glib::ustring TAG_FOREGROUND_PREFIX     {"foreground_"};
 const inline static gchar* TAG_BACKGROUND          {"background"};
+const inline static Glib::ustring TAG_BACKGROUND_PREFIX     {"background_"};
 const inline static gchar* TAG_STYLE               {"style"};
+const inline static Glib::ustring TAG_STYLE_PREFIX          {"style_"};
 const inline static gchar* TAG_UNDERLINE           {"underline"};
+const inline static Glib::ustring TAG_UNDERLINE_PREFIX      {"underline_"};
 const inline static gchar* TAG_STRIKETHROUGH       {"strikethrough"};
+const inline static Glib::ustring TAG_STRIKETHROUGH_PREFIX  {"strikethrough_"};
 const inline static gchar* TAG_INDENT              {"indent"};
+const inline static Glib::ustring TAG_INDENT_PREFIX         {"indent_"};
 const inline static gchar* TAG_SCALE               {"scale"};
+const inline static Glib::ustring TAG_SCALE_PREFIX          {"scale_"};
 const inline static gchar* TAG_INVISIBLE           {"invisible"};
+const inline static Glib::ustring TAG_INVISIBLE_PREFIX      {"invisible_"};
 const inline static gchar* TAG_FAMILY              {"family"};
+const inline static Glib::ustring TAG_FAMILY_PREFIX         {"family_"};
 const inline static gchar* TAG_JUSTIFICATION       {"justification"};
+const inline static Glib::ustring TAG_JUSTIFICATION_PREFIX  {"justification_"};
 const inline static gchar* TAG_LINK                {"link"};
+const inline static Glib::ustring TAG_LINK_PREFIX           {"link_"};
 const inline static gchar* TAG_SEPARATOR           {"separator"};
 const inline static gchar* TAG_SEPARATOR_ANSI_REPR {"---------"};
 
@@ -522,6 +534,10 @@ const inline static std::vector<const gchar*> _NODE_CUSTOM_ICONS {
     "ct_sk",                // 246
     "ct_visible",           // 247
     "ct_invisible",         // 248
+    "ct_arrow-left",        // 249
+    "ct_arrow-right",       // 250
+    "ct_arrow-down",        // 251
+    "ct_arrow-up",          // 252
 };
 
 const inline static std::vector<int> NODE_CUSTOM_ICONS_ORDERED {
@@ -536,7 +552,7 @@ const inline static std::vector<int> NODE_CUSTOM_ICONS_ORDERED {
     50/*pin*/, 51/*anchor*/, 52/*edit*/, 53/*save*/, 54/*execute*/, 55/*preferences*/, 56/*clear*/, 57/*stop*/, 58/*close*/, 59/*quit app*/,
     60/*file*/, 141/*7zip*/, 44/*folder*/,
     61/*print*/, 62/*attachment*/, 63/*link*/, 64/*linkweb*/, 65/*network*/,
-    66/*back*/, 67/*down*/, 68/*forward*/, 69/*up*/, 70/*jump to*/, 71/*zoom out*/, 72/*zoom in*/,
+    66/*back*/, 67/*down*/, 68/*forward*/, 69/*up*/, 70/*jump to*/, 71/*zoom out*/, 72/*zoom in*/, 249/*left*/, 250/*right*/, 251/*down*/, 252/*up*/,
     95/*sports*/, 96/*briefcase*/, 159/*building*/, 98/*chart*/, 145/*invest*/, 104/*money*/,
     97/*camera*/, 99/*clapperboard*/, 100/*maths*/, 101/*games*/, 144/*dictionary*/,
     157/*bike*/, 161/*car*/, 160/*bus*/, 242/*ship*/, 203/*airplane*/, 239/*rocket*/,
