@@ -1,7 +1,7 @@
 /*
  * ct_dialogs.h
  *
- * Copyright 2009-2024
+ * Copyright 2009-2025
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -173,7 +173,8 @@ Gtk::TreeIter choose_item_dialog(Gtk::Window& parent,
                                  const Glib::ustring& title,
                                  Glib::RefPtr<CtChooseDialogListStore> model,
                                  const gchar* single_column_name = nullptr,
-                                 const std::string& pathToSelect = "0");
+                                 const std::string& pathToSelect = "0",
+                                 std::optional<std::pair<int,int>> use_size = std::nullopt);
 
 // Dialog to select between the Selected Node/Selected Node + Subnodes/All Tree
 CtExporting selnode_selnodeandsub_alltree_dialog(Gtk::Window& parent,
