@@ -28,7 +28,7 @@
 
 #include <glibmm/i18n.h>
 #include <gtkmm.h>
-#include <gtksourceviewmm.h>
+#include <gtksourceview/gtksource.h>
 #include "ct_treestore.h"
 #include "ct_misc_utils.h"
 #include "ct_menu.h"
@@ -42,6 +42,7 @@
 struct CtStatusBar
 {
     Gtk::Statusbar   statusBar;
+    Gtk::Label       cursorPos;
     guint            statusId;
     Gtk::ProgressBar progressBar;
     Gtk::Button      stopButton;
@@ -53,9 +54,12 @@ struct CtStatusBar
     void push(const Glib::ustring& text) { statusBar.push(text, statusId); }
     void pop() { statusBar.pop(statusId); }
     void update_status(const Glib::ustring& text) { pop(); push(text); }
+    void new_cursor_pos(const int r, const int c);
 
 private:
-    bool _progress_stop;
+    bool _progress_stop{false};
+    int _r{-1};
+    int _c{-1};
 };
 
 struct CtWinHeader
@@ -87,8 +91,7 @@ public:
         Gtk::IconTheme*          pGtkIconTheme,
         Glib::RefPtr<Gtk::TextTagTable> rGtkTextTagTable,
         Glib::RefPtr<Gtk::CssProvider> rGtkCssProvider,
-        Gsv::LanguageManager*    pGsvLanguageManager,
-        Gsv::StyleSchemeManager* pGsvStyleSchemeManager,
+        GtkSourceLanguageManager* pGtkSourceLanguageManager,
         CtStatusIcon*            pCtStatusIcon
     );
     virtual ~CtMainWin();
@@ -117,7 +120,7 @@ public:
                                    const CtTreeIter* give_tree_iter = nullptr);
     void load_buffer_from_state(std::shared_ptr<CtNodeState> state, CtTreeIter tree_iter);
     void re_load_current_buffer(const bool new_machine_state = false);
-    void switch_buffer_text_source(Glib::RefPtr<Gsv::Buffer> text_buffer, CtTreeIter tree_iter, const std::string& new_syntax, const std::string& old_syntax);
+    void switch_buffer_text_source(Glib::RefPtr<Gtk::TextBuffer> text_buffer, CtTreeIter tree_iter, const std::string& new_syntax, const std::string& old_syntax);
     void update_window_save_not_needed();
     bool get_file_save_needed();
 
@@ -143,8 +146,7 @@ public:
     CtStateMachine&                   get_state_machine() { return _ctStateMachine; }
     Glib::RefPtr<Gtk::TextTagTable>&  get_text_tag_table() { return _rGtkTextTagTable; }
     Glib::RefPtr<Gtk::CssProvider>&   get_css_provider()   { return _rGtkCssProvider; }
-    Gsv::LanguageManager*             get_language_manager() { return _pGsvLanguageManager; }
-    Gsv::StyleSchemeManager*          get_style_scheme_manager() { return _pGsvStyleSchemeManager; }
+    GtkSourceLanguageManager*         get_language_manager() { return _pGtkSourceLanguageManager; }
     Gtk::StatusIcon*                  get_status_icon() { return _pCtStatusIcon->get(); }
     Gtk::ScrolledWindow&              getScrolledwindowText() { return _scrolledwindowText; }
 
@@ -157,12 +159,12 @@ public:
 public:
     const char*               get_code_icon_name(std::string code_type);
     Gtk::Image*               new_managed_image_from_stock(const std::string& stockImage, Gtk::BuiltinIconSize size);
-    void                      apply_syntax_highlighting(Glib::RefPtr<Gsv::Buffer> text_buffer, const std::string& syntax, const bool forceReApply);
+    void                      apply_syntax_highlighting(Glib::RefPtr<Gtk::TextBuffer> text_buffer, const std::string& syntax, const bool forceReApply);
     void                      reapply_syntax_highlighting(const char target/*'r':RichText, 'p':PlainTextNCode, 't':Table*/);
     void                      resetup_for_syntax(const char target/*'r':RichText, 'p':PlainTextNCode*/);
     void                      codeboxes_reload_toolbar();
-    Glib::RefPtr<Gsv::Buffer> get_new_text_buffer(const Glib::ustring& textContent="");
-    const std::string         get_text_tag_name_exist_or_create(const std::string& propertyName, const std::string& propertyValue);
+    Glib::RefPtr<Gtk::TextBuffer> get_new_text_buffer(const Glib::ustring& textContent="");
+    std::string               get_text_tag_name_exist_or_create(const std::string& propertyName, const std::string& propertyValue);
     void                      apply_scalable_properties(Glib::RefPtr<Gtk::TextTag> rTextTag, CtScalableTag* pCtScalableTag);
     Glib::ustring             sourceview_hovering_link_get_tooltip(const Glib::ustring& link);
     bool                      apply_tag_try_automatic_bounds(Glib::RefPtr<Gtk::TextBuffer> text_buffer, Gtk::TextIter iter_start);
@@ -259,7 +261,7 @@ private:
 
     void _reset_CtTreestore_CtTreeview();
     void _ensure_curr_doc_in_recent_docs();
-    void _zoom_tree(bool is_increase);
+    void _zoom_tree(const std::optional<bool> is_increase);
     bool _try_move_focus_to_anchored_widget_if_on_it();
 
 private:
@@ -271,8 +273,7 @@ private:
     Gtk::IconTheme*              _pGtkIconTheme;
     Glib::RefPtr<Gtk::TextTagTable> _rGtkTextTagTable;
     Glib::RefPtr<Gtk::CssProvider>  _rGtkCssProvider;
-    Gsv::LanguageManager*        _pGsvLanguageManager;
-    Gsv::StyleSchemeManager*     _pGsvStyleSchemeManager;
+    GtkSourceLanguageManager*    const _pGtkSourceLanguageManager;
     CtStatusIcon*                _pCtStatusIcon;
 
     std::unique_ptr<CtActions>        _uCtActions;
