@@ -1,7 +1,7 @@
 /*
  * ct_storage_multifile.cc
  *
- * Copyright 2009-2024
+ * Copyright 2009-2025
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -33,6 +33,11 @@
 /*static*/const std::string CtStorageMultiFile::NODE_XML{"node.xml"};
 /*static*/const std::string CtStorageMultiFile::BEFORE_SAVE{".before"};
 
+CtStorageMultiFile::CtStorageMultiFile(CtMainWin* pCtMainWin)
+ : _pCtMainWin{pCtMainWin}
+ , _pCtConfig{pCtMainWin->get_ct_config()}
+{}
+
 bool CtStorageMultiFile::save_treestore(const fs::path& dir_path,
                                         const CtStorageSyncPending& syncPending,
                                         Glib::ustring& error,
@@ -109,7 +114,7 @@ bool CtStorageMultiFile::save_treestore(const fs::path& dir_path,
                 }
             }
 
-            // save subnodes
+            // save list of subnodes
             Glib::file_set_contents(Glib::build_filename(dir_path.string(), SUBNODES_LST),
                                     str::join_numbers(subnodes_list, ","));
         }
@@ -125,20 +130,38 @@ bool CtStorageMultiFile::save_treestore(const fs::path& dir_path,
             // update changed nodes
             const std::list<std::pair<CtTreeIter, CtStorageNodeState>> nodes_to_write = CtStorageControl::get_sorted_by_level_nodes_to_write(
                 &_pCtMainWin->get_tree_store(), syncPending.nodes_to_write_dict);
+            // at the time of saving, an embedded file could be cut and pasted from one node text buffer to another
+            // so only after all the nodes are saved we can remove the files that belong to a node and are no longer referenced
+            std::list<fs::path> embFiles_referenced;
             bool any_hier{false};
-            for (const auto& node_pair : nodes_to_write) {
-                _nodes_to_multifile(&node_pair.first,
-                                    _get_node_dirpath(node_pair.first),
-                                    error,
-                                    &storage_cache,
-                                    node_pair.second,
-                                    export_type,
-                                    pExpoMasterReassign,
-                                    0,
-                                    -1);
-                if (not any_hier and node_pair.second.hier) {
+            for (const std::pair<CtTreeIter, CtStorageNodeState>& node_pair : nodes_to_write) {
+                const CtTreeIter& ct_tree_iter = node_pair.first;
+                const CtStorageNodeState& node_state = node_pair.second;
+                const fs::path curr_node_dirpath = _get_node_dirpath(ct_tree_iter);
+                if (not _nodes_to_multifile(&ct_tree_iter,
+                                            curr_node_dirpath,
+                                            error,
+                                            &storage_cache,
+                                            node_state,
+                                            export_type,
+                                            pExpoMasterReassign,
+                                            0,
+                                            -1))
+                {
+                    return false;
+                }
+                if (not any_hier and node_state.hier) {
                     any_hier = true;
                 }
+                if (_pCtConfig->embfileMFNameOnDisk) {
+                    for (CtAnchoredWidget* pAnchoredWidget : ct_tree_iter.get_anchored_widgets_fast()) {
+                        if (CtAnchWidgType::ImageEmbFile == pAnchoredWidget->get_type()) {
+                            auto pCtImageEmbFile = dynamic_cast<CtImageEmbFile*>(pAnchoredWidget);
+                            embFiles_referenced.push_back(curr_node_dirpath / pCtImageEmbFile->get_file_name());
+                            //spdlog::debug("++ referenced {}/{}", curr_node_dirpath.c_str(), pCtImageEmbFile->get_file_name().c_str());
+                        }
+                    }
+                }
             }
             if (not syncPending.nodes_to_rm_set.empty()) {
                 // remove nodes and their sub nodes
@@ -150,6 +173,24 @@ bool CtStorageMultiFile::save_treestore(const fs::path& dir_path,
                     any_hier = true;
                 }
             }
+            // remove no longer referenced embedded files
+            for (const std::pair<CtTreeIter, CtStorageNodeState>& node_pair : nodes_to_write) {
+                const CtTreeIter& ct_tree_iter = node_pair.first;
+                const fs::path curr_node_dirpath = _get_node_dirpath(ct_tree_iter);
+                for (const fs::path& filepath : fs::get_dir_entries(curr_node_dirpath)) {
+                    if (fs::is_regular_file(filepath)) {
+                        const fs::path filename = filepath.filename();
+                        if (filename != NODE_XML and
+                            filename != SUBNODES_LST and
+                            not CtStrUtil::is_256sum(filename.stem().c_str()) and
+                            embFiles_referenced.end() == std::find(embFiles_referenced.begin(), embFiles_referenced.end(), filepath))
+                        {
+                            spdlog::debug("-- rm {} as not referenced", filepath.c_str());
+                            fs::remove(filepath);
+                        }
+                    }
+                }
+            }
             if (any_hier) {
                 // full tree hierarchy verification needed
                 _verify_update_hierarchy(nullptr/*ct_tree_iter_parent*/, _dir_path);
@@ -220,6 +261,11 @@ fs::path CtStorageMultiFile::_get_node_dirpath(const CtTreeIter& ct_tree_iter) c
     return _dir_path / hierarchical_path;
 }
 
+fs::path CtStorageMultiFile::get_embedded_filepath(const CtTreeIter& ct_tree_iter, const std::string& filename) const
+{
+    return _get_node_dirpath(ct_tree_iter) / filename;
+}
+
 void CtStorageMultiFile::_remove_disk_node_with_children(const gint64 node_id)
 {
     // the nodes must be passed to the BackupEncrypt thread from the leaves towards the root
@@ -236,11 +282,12 @@ void CtStorageMultiFile::_remove_disk_node_with_children(const gint64 node_id)
             f_iterative_queue_nodes_for_removal(node_dirpath);
         }
         // eventually process myself
-        std::shared_ptr<CtBackupEncryptData> pBackupEncryptData = std::make_shared<CtBackupEncryptData>();
+        auto pBackupEncryptData = std::make_shared<CtBackupEncryptData>();
         pBackupEncryptData->backupType = CtBackupType::MultiFile;
         pBackupEncryptData->needEncrypt = false;
         pBackupEncryptData->file_path = _dir_path.string();
         pBackupEncryptData->main_backup = curr_node_dirpath.string();
+        pBackupEncryptData->p_mod_time = nullptr;
         _pCtMainWin->get_ct_storage()->backupEncryptDEQueue.push_back(pBackupEncryptData);
         _already_queued_for_removal.insert(curr_node_id);
     };
@@ -260,7 +307,7 @@ void CtStorageMultiFile::_write_bookmarks_to_disk(const std::list<gint64>& bookm
     }
 }
 
-void CtStorageMultiFile::_hier_try_move_node(const fs::path& dir_path_to)
+void CtStorageMultiFile::_hier_try_move_existing_node_to_path(const fs::path& dir_path_to)
 {
     const fs::path dir_name = dir_path_to.filename();
     fs::path dir_path_from;
@@ -281,7 +328,7 @@ void CtStorageMultiFile::_hier_try_move_node(const fs::path& dir_path_to)
     };
     f_find_dir_from(_dir_path);
     if (not dir_path_from.empty()) {
-        spdlog::debug("{} -> {}", dir_path_from, dir_path_to);
+        spdlog::debug("{} -> {}", dir_path_from.string(), dir_path_to.string());
         fs::move_file(dir_path_from, dir_path_to);
     }
 }
@@ -301,7 +348,7 @@ bool CtStorageMultiFile::_nodes_to_multifile(const CtTreeIter* ct_tree_iter,
         node_state.is_update_of_existing and
         not fs::is_directory(dir_path))
     {
-        _hier_try_move_node(dir_path);
+        _hier_try_move_existing_node_to_path(dir_path);
     }
     if (not fs::is_directory(dir_path) and
         g_mkdir(dir_path.c_str(), 0755) < 0)
@@ -312,8 +359,8 @@ bool CtStorageMultiFile::_nodes_to_multifile(const CtTreeIter* ct_tree_iter,
     if (node_state.buff or node_state.prop) {
         fs::path dir_before_save;
         if (CtExporting::NONESAVE == export_type) {
-            // create folder of previous node.xml and widgets
-            // (if binaries not changed, won't re-save but move over)
+            // create folder of previous node.xml and 256sum named widgets
+            // (if 256sum not changed, won't re-save but move over)
             dir_before_save = dir_path / BEFORE_SAVE;
             if (fs::is_directory(dir_before_save)) {
                 (void)fs::remove_all(dir_before_save);
@@ -325,7 +372,9 @@ bool CtStorageMultiFile::_nodes_to_multifile(const CtTreeIter* ct_tree_iter,
             for (const fs::path& file_from : fs::get_dir_entries(dir_path)) {
                 if (fs::is_regular_file(file_from)) {
                     const fs::path name_from = file_from.filename();
-                    if (name_from != SUBNODES_LST) {
+                    const bool do_move = _pCtConfig->embfileMFNameOnDisk ?
+                        (name_from == NODE_XML or CtStrUtil::is_256sum(name_from.stem().c_str())) : (name_from != SUBNODES_LST);
+                    if (do_move) {
                         const fs::path file_to = dir_before_save / name_from;
                         fs::move_file(file_from, file_to);
                     }
@@ -348,14 +397,35 @@ bool CtStorageMultiFile::_nodes_to_multifile(const CtTreeIter* ct_tree_iter,
             );
 
             // write file
-            xml_doc_node.write_to_file_formatted(Glib::build_filename(dir_path.string(), NODE_XML));
+            const std::string xml_filepath = Glib::build_filename(dir_path.string(), NODE_XML);
+            xml_doc_node.write_to_file_formatted(xml_filepath);
+
+            // parse back
+            try {
+                std::unique_ptr<xmlpp::DomParser> parser = CtStorageXml::get_parser(xml_filepath);
+            }
+            catch (std::exception& ex) {
+                error = fmt::format("parse {} after write: {}", xml_filepath, ex.what());
+                if (CtExporting::NONESAVE == export_type) {
+                    // restore from BEFORE_SAVE
+                    for (const fs::path& file_from : fs::get_dir_entries(dir_before_save)) {
+                        if (fs::is_regular_file(file_from)) {
+                            const fs::path name_from = file_from.filename();
+                            const fs::path file_to = dir_path / name_from;
+                            fs::move_file(file_from, file_to);
+                        }
+                    }
+                }
+                return false;
+            }
         }
         if (CtExporting::NONESAVE == export_type) {
-            std::shared_ptr<CtBackupEncryptData> pBackupEncryptData = std::make_shared<CtBackupEncryptData>();
+            auto pBackupEncryptData = std::make_shared<CtBackupEncryptData>();
             pBackupEncryptData->backupType = CtBackupType::MultiFile;
             pBackupEncryptData->needEncrypt = false;
             pBackupEncryptData->file_path = _dir_path.string();
             pBackupEncryptData->main_backup = dir_before_save.string();
+            pBackupEncryptData->p_mod_time = nullptr;
             _pCtMainWin->get_ct_storage()->backupEncryptDEQueue.push_back(pBackupEncryptData);
         }
     }
@@ -390,7 +460,7 @@ bool CtStorageMultiFile::_nodes_to_multifile(const CtTreeIter* ct_tree_iter,
                 }
             }
 
-            // save subnodes
+            // save list of subnodes
             Glib::file_set_contents(Glib::build_filename(dir_path.string(), SUBNODES_LST),
                                     str::join_numbers(subnodes_list, ","));
         }
@@ -432,7 +502,7 @@ bool CtStorageMultiFile::_nodes_to_multifile(const CtTreeIter* ct_tree_iter,
         }
     }
     catch (Glib::Error& error) {
-        spdlog::error("{} {}", __FUNCTION__, error.what());
+        spdlog::error("{} {}", __FUNCTION__, error.what().raw());
     }
     return false;
 }
@@ -479,8 +549,51 @@ bool CtStorageMultiFile::populate_treestore(const fs::path& dir_path, Glib::ustr
         f_nodes_from_multifile = [&](const fs::path& nodedir, const gint64 sequence, Gtk::TreeIter parent_iter) {
             bool has_duplicated_id{false};
             bool is_shared_non_master{false};
-            std::unique_ptr<xmlpp::DomParser> parser = CtStorageXml::get_parser(nodedir / NODE_XML);
-            xmlpp::Node* xml_node = parser->get_document()->get_root_node()->get_first_child("node");
+            std::unique_ptr<xmlpp::DomParser> pParser;
+            fs::path node_xml_path = nodedir / NODE_XML;
+            bool parsingOk{false};
+            try {
+                pParser = CtStorageXml::get_parser(node_xml_path);
+                parsingOk = true;
+            }
+            catch (std::exception& ex) {
+                spdlog::error("parse {} : {} - trying first backup...", node_xml_path.string(), ex.what());
+            }
+            if (not parsingOk) {
+                std::string first_backup_dir;
+                CtStorageControl::get_first_backup_file_or_dir(first_backup_dir, _dir_path.string(), _pCtMainWin->get_ct_config());
+                int missing_backup{0};
+                for (int b = 0; b < 100; ++b) {
+                    const fs::path curr_backup_dir = first_backup_dir + str::repeat(CtConst::CHAR_TILDE, b).raw();
+                    if (fs::is_directory(curr_backup_dir)) {
+                        missing_backup = 0;
+                        spdlog::debug("backed up data, {} found", curr_backup_dir.string());
+                        const fs::path backup_node_xml_path = curr_backup_dir / nodedir.filename() / NODE_XML;
+                        try {
+                            pParser = CtStorageXml::get_parser(backup_node_xml_path);
+                            parsingOk = true;
+                        }
+                        catch (std::exception& ex) {
+                            spdlog::error("parse {} : {} - trying backup {}...", node_xml_path.string(), ex.what(), b+2);
+                        }
+                        if (parsingOk) {
+                            if (fs::exists(node_xml_path)) {
+                                fs::move_file(node_xml_path, node_xml_path.parent_path() / (node_xml_path.stem() + std::string{"_BAD.xml"}));
+                            }
+                            spdlog::debug("parse backed up data ok, copying {} -> {}", backup_node_xml_path.string(), node_xml_path.string());
+                            fs::copy_file(backup_node_xml_path, node_xml_path);
+                            if (error.empty()) error += _("A Restore From Backup Was Necessary For:");
+                            error += "\n\n" + node_xml_path.string();
+                            break;
+                        }
+                    }
+                    else {
+                        spdlog::debug("?? backed up data, {} missing", curr_backup_dir.string());
+                        if (++missing_backup > 3) break;
+                    }
+                }
+            }
+            xmlpp::Node* xml_node = pParser->get_document()->get_root_node()->get_first_child("node");
             auto xml_element = static_cast<xmlpp::Element*>(xml_node);
             Gtk::TreeIter new_iter = CtStorageXmlHelper{_pCtMainWin}.node_from_xml(
                 xml_element,
@@ -583,13 +696,13 @@ void CtStorageMultiFile::import_nodes(const fs::path& dir_path, const Gtk::TreeI
     }
 }
 
-Glib::RefPtr<Gsv::Buffer> CtStorageMultiFile::get_delayed_text_buffer(const gint64 node_id,
-                                                                      const std::string& syntax,
-                                                                      std::list<CtAnchoredWidget*>& widgets) const
+Glib::RefPtr<Gtk::TextBuffer> CtStorageMultiFile::get_delayed_text_buffer(const gint64 node_id,
+                                                                          const std::string& syntax,
+                                                                          std::list<CtAnchoredWidget*>& widgets) const
 {
     if (_delayed_text_buffers.count(node_id) == 0) {
         spdlog::error("!! {} node_id {}", __FUNCTION__, node_id);
-        return Glib::RefPtr<Gsv::Buffer>{};
+        return Glib::RefPtr<Gtk::TextBuffer>{};
     }
     std::shared_ptr<xmlpp::Document> node_buffer = _delayed_text_buffers[node_id];
     auto xml_element = dynamic_cast<xmlpp::Element*>(node_buffer->get_root_node()->get_first_child());
