@@ -73,6 +73,7 @@ const double CtTextView::TEXT_SCROLL_MARGIN{0.1}; // margin as a [0.0,0.5] fract
 
 CtAnchoredWidget::CtAnchoredWidget(CtMainWin* pCtMainWin, const int charOffset, const std::string& justification)
  : _pCtMainWin{pCtMainWin}
+ , _pCtConfig{pCtMainWin->get_ct_config()}
  , _charOffset{charOffset}
  , _justification{justification}
 {
@@ -98,8 +99,7 @@ void CtAnchoredWidget::insertInTextBuffer(Glib::RefPtr<Gtk::TextBuffer> rTextBuf
         textIterEnd.forward_char();
         Glib::ustring tagName = _pCtMainWin->get_text_tag_name_exist_or_create(CtConst::TAG_JUSTIFICATION, _justification);
         rTextBuffer->apply_tag_by_name(tagName, textIterStart, textIterEnd);
-        static const std::string invisible_tag{"invisible_"};
-        std::optional<Glib::ustring> optTag = CtTextIterUtil::iter_get_tag_startingwith(textIterStart, invisible_tag);
+        std::optional<Glib::ustring> optTag = CtTextIterUtil::iter_get_tag_startingwith(textIterStart, CtConst::TAG_INVISIBLE_PREFIX);
         if (optTag.has_value()) {
             //spdlog::debug("{}", optTag.value().c_str());
             set_hidden(true);
